summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu/webengine.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/emu/webengine.h')
-rw-r--r--src/emu/webengine.h10
1 files changed, 2 insertions, 8 deletions
diff --git a/src/emu/webengine.h b/src/emu/webengine.h
index a30826eb92d..85b5efa8342 100644
--- a/src/emu/webengine.h
+++ b/src/emu/webengine.h
@@ -13,7 +13,7 @@
#ifndef __WEB_ENGINE_H__
#define __WEB_ENGINE_H__
-struct mg_context; // Handle for the HTTP service itself
+struct mg_server; // Handle for the HTTP server itself
struct mg_connection; // Handle for the individual connection
class web_engine
@@ -27,12 +27,7 @@ public:
void close();
void set_machine(running_machine &machine) { m_machine = &machine; }
-
- void websocket_ready_handler(struct mg_connection *conn);
- int websocket_data_handler(struct mg_connection *conn, int flags, char *data, size_t data_len);
int begin_request_handler(struct mg_connection *conn);
- int begin_http_error_handler(struct mg_connection *conn, int status);
- void *websocket_keepalive();
protected:
// getters
running_machine &machine() const { return *m_machine; }
@@ -43,10 +38,9 @@ private:
// internal state
emu_options & m_options;
running_machine * m_machine;
- struct mg_context * m_ctx;
+ struct mg_server * m_server;
osd_ticks_t m_lastupdatetime;
bool m_exiting_core;
- simple_list<simple_list_wrapper<mg_connection> > m_websockets;
};
#endif /* __web_engine_H__ */